@@ -53,14 +53,17 @@ test.describe('Notebook Toolbar', () => {
 
   test('Paste cell', async ({ page }) => {
     // Cut cell to populate clipboard
-    await page.notebook.selectCells(1);
+    await page.notebook.selectCells(0);
     await page.notebook.clickToolbarItem('cut');
 
     const imageName = 'paste-cell.png';
-    await page.notebook.selectCells(2);
+    await page.notebook.selectCells(1);
     await page.notebook.clickToolbarItem('paste');
     const nbPanel = await page.notebook.getNotebookInPanel();
 
+    await expect
+      .soft(page.locator('.jp-Notebook-cell.jp-mod-active .jp-cell-toolbar'))
+      .toBeVisible();
     expect(await nbPanel.screenshot()).toMatchSnapshot(imageName);
   });
 
@@ -79,7 +82,6 @@ test.describe('Notebook Toolbar', () => {
 
     await page.notebook.clickToolbarItem('run');
     await page.waitForSelector('text=8');
-    // await page.notebook.waitForRun();
 
     const nbPanel = await page.notebook.getNotebookInPanel();
 
@@ -130,7 +132,9 @@ test('Toolbar items act on owner widget', async ({ page }) => {
   expect(classlist.split(' ')).not.toContain('jp-mod-current');
 
   // When clicking on toolbar item of the first file
-  await (await panel1.$('button[title="Insert a cell below (B)"]')).click();
+  await (
+    await panel1.$('jp-button[data-command="notebook:insert-cell-below"]')
+  ).click();
 
   // Then the first file is activated and the action is performed
   const classlistEnd = await tab1.getAttribute('class');
